// ****************************************************************************
// Projekt      : LCD Module DOGM163S-A
// Prozessor    : PIC18F45K22 @ 40Mhz
// Compiler     : MPLAB XC8 V2.45
// Autor        : Stefan Gluekler
// Datum        : 2023.12.18
// Version      : V2.1
// Beschreibung : Ansteurung des LCD-Moduls DOGM163S-A
//                und dem "VFEI - PIC Board V2015"
// ****************************************************************************

#ifndef _LCD_MODULE_DOGM163S_A_H_
#define _LCD_MODULE_DOGM163S_A_H_

#include <stdbool.h>        // Include for data type 'bool' and keywords 'true' and 'false'
#include <stdint.h>         // Include for defines the standard integer types per ISO/IEC 9899:1999

#define LCD_LINES         3
#define LCD_CHARACHTERS   16

// Initialisieren des LCD-Moduls
void LCD_Module_Init(void);

// Setzen der Helligkeit der Hintergrund-Beleuchtung
// percent  -> Helligkeit der Hintergrund-Beleuchtung (0-100)
void LCD_Module_SetBacklight(uint8_t percent);

// Setzen des LCD Kontrastes
// percent  -> Kontrast des LCD (0-100)
void LCD_Module_SetContrast(uint8_t percent);

// Loeschen aller Zeilen
void LCD_Module_ClearAll(void);

// Loeschen einer Zeile
// line     -> Zeile des Curors (1-3)
void LCD_Module_ClearLine(uint8_t line);

// Setzen des Cursor-Mode
// cursorOn    = TRUE   -> Cursor ist sichtbar
// cursorOn    = FALSE  -> Cursor ist unsichtbar
// cursorBlink = TRUE   -> Cursor blinkt
// cursorBlink = FALSE  -> Cursor ist fix
void LCD_Module_SetCursorMode(bool cursorOn,
                              bool cursorBlink);

// Setzen der Cursor-Position auf Position und Zeile
// position -> Position des Cursors (1-16)
// line     -> Zeile des Curors (1-3)
void LCD_Module_SetCursorPosition(uint8_t position,
                                  uint8_t line);

// Ausgabe eines Zeichen
// charachter  ->  Zeichen dies ausgegeben werden soll (char)
void LCD_Module_WriteChar(char charachter);

// Ausgabe eines Strings
// romString   ->  String der ausgegeben werden soll (char[])
void LCD_Module_WriteString(const char *romString);

// Formatierte Ausgabe eines Strings
// romString   ->  String der ausgegeben werden soll (char[])
// romFormat   ->  Gewuenschtes Ausgabeformat
void LCD_Module_WriteFormated_String(const char *romString,
                                     const char *romFormat);

// Formatierte Ausgabe einer int8-/int16-Variable
// value      ->  Wert der ausgegeben werden soll
// romFormat  ->  Gewuenschtes Ausgabeformat
void LCD_Module_WriteFormated_Int16(int16_t value,
                                    const char *romFormat);

// Formatierte Ausgabe einer uint8/uint16-Variable
// value      ->  Wert der ausgegeben werden soll
// romFormat  ->  Gewuenschtes Ausgabeformat
void LCD_Module_WriteFormated_UInt16(uint16_t value,
                                     const char *romFormat);

// Formatierte Ausgabe einer int32-Variable
// value      ->  Wert der ausgegeben werden soll
// romFormat  ->  Gewuenschtes Ausgabeformat
void LCD_Module_WriteFormated_Int32(int32_t value,
                                    const char *romFormat);

// Formatierte Ausgabe einer uint32-Variable
// value      ->  Wert der ausgegeben werden soll
// romFormat  ->  Gewuenschtes Ausgabeformat
void LCD_Module_WriteFormated_UInt32(uint32_t value,
                                     const char *romFormat);

#endif
